@@ -271,13 +271,13 @@ class Client(commandServer, encrypt, Desktop):
             p = process(mountCmd,"-t","cifs","-o",
                 "cache=loose,user=%s,uid=%d,gid=%d,noperm"%(userName,uid,gid),
                 "//%s/%s"%(host,res),rpath,
-                envdict={"PASSWD":userPwd})
+                envdict={"PASSWD":userPwd},stderr=STDOUT)
             return p.success()
         else:
             p = process(mountCmd,"-t","cifs","-o",
                 "cache=loose,user=%s"%userName,
                 "//%s/%s"%(host,res),rpath,
-                envdict={"PASSWD":userPwd})
+                envdict={"PASSWD":userPwd},stderr=STDOUT)
             return p.success()
 
     def mountSleepRes(self,host,userName,userPwd,res,rpath,uid=None,gid=None):
@@ -1059,7 +1059,7 @@ class Client(commandServer, encrypt, Desktop):
             if remotePw:
                 self.printERROR(_("Wrong password"))
             # не запрашвать пароль при загрузке системы
-            if not path.exists('/prc/self/fd/0') or \
+            if not path.exists('/proc/self/fd/0') or \
                 os.readlink('/proc/self/fd/0') != '/dev/console':
                 yield self.askPassword(\
                         _("Domain password for the desktop"),False)
