@@ -655,3 +655,8 @@ class VariableClClientSymlinks(ReadonlyVariable):
             skipFiles))).search
         return filter(lambda x:not reSkip(x),
                find(self.Get('ur_home_path'),onefilesystem=True,filetype='l'))
+
+class VariableClClientNscdCache(Variable):
+    """
+    Частота обновления кэша nscd при работе в домене в часах
+    """
